
# This file was generated by 'versioneer.py' (0.14) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.23.2+1.g67a89c7'
version_full = '67a89c78871b234ffad53b23e8e4a76bf1fe766c'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}




#  tests for llvmlite-0.23.2-py35hc454e04_0 (this is a generated file);
print('===== testing package: llvmlite-0.23.2-py35hc454e04_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
from llvmlite.tests import main

# Enable tests for distribution only
os.environ['LLVMLITE_DIST_TEST'] = '1'
main()
#  --- run_test.py (end) ---

print('===== llvmlite-0.23.2-py35hc454e04_0 OK =====');
print("import: 'llvmlite'")
import llvmlite

print("import: 'llvmlite.binding'")
import llvmlite.binding

